@@ -2,7 +2,7 @@
  * Programmer(s): Cody J. Balos, Aaron Collier and Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2025, Lawrence Livermore National Security,
+ * Copyright (c) 2025-2026, Lawrence Livermore National Security,
  * University of Maryland Baltimore County, and the SUNDIALS contributors.
  * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
@@ -47,12 +47,12 @@
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "7.5.0"
+#define SUNDIALS_VERSION "7.6.0"
 #define SUNDIALS_VERSION_MAJOR 7
-#define SUNDIALS_VERSION_MINOR 5
+#define SUNDIALS_VERSION_MINOR 6
 #define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
-#define SUNDIALS_GIT_VERSION "v7.5.0"
+#define SUNDIALS_GIT_VERSION "v7.6.0"
 
 
 /* ------------------------------------------------------------------
@@ -115,7 +115,7 @@
 /* Build metadata */
 #define SUN_C_COMPILER "GNU"
 #define SUN_C_COMPILER_VERSION "15.2.1"
-#define SUN_C_COMPILER_FLAGS "-march=native -O3 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -mpclmul -g1 -ffile-prefix-map=/startdir/src=/usr/src/debug/sundials -flto=auto"
+#define SUN_C_COMPILER_FLAGS "-march=x86-64-v4 -mtune=generic -O3 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -mpclmul -g1 -ffile-prefix-map=/startdir/src=/usr/src/debug/sundials -flto=auto"
 
 #define SUN_CXX_COMPILER ""
 #define SUN_CXX_COMPILER_VERSION ""
@@ -127,8 +127,8 @@
 
 #define SUN_BUILD_TYPE "RelWithDebInfo"
 
-#define SUN_JOB_ID "20251028070119"
-#define SUN_JOB_START_TIME "20251028070119"
+#define SUN_JOB_ID "20260126203433"
+#define SUN_JOB_START_TIME "20260126203433"
 
 #define SUN_TPL_LIST "MPI;OPENMP;KLU;BLAS_LAPACK;PTHREAD"
 #define SUN_TPL_LIST_SIZE ""
@@ -192,7 +192,7 @@
 
 /* OpenMP */
 #define SUNDIALS_OPENMP_ENABLED
-#define SUN_OPENMP_VERSION ""
+#define SUN_OPENMP_VERSION "4.5"
 
 /* PETSC */
 /* #undef SUNDIALS_PETSC_ENABLED */
@@ -276,6 +276,9 @@
 /* SYCL options */
 /* #undef SUNDIALS_SYCL_2020_UNSUPPORTED */
 
+/* Python options */
+/* #undef SUNDIALS_ENABLE_PYTHON */
+
 
 /* ------------------------------------------------------------------
  * SUNDIALS modules enabled
